Heylo FAQs | Frequently Asked Questions about Our Products & Service – Heylo MG
Description: Find answers to your questions about Heylo's magnesium-infused products, shipping, subscriptions, ingredients, and more. Learn how our natural, vegan drinks can support your mental health and wellness.

Skip to content

# FAQs

- Choosing a selection results in a full page refresh.
- Opens in a new window.

★ Reviews

### Let customers speak for us

57 reviews
Write a review
89%
(51)
5%
(3)
2%
(1)
2%
(1)
2%
(1)
45
M
April Subscription Box
Michele C. (Australia)
Delivery delay

Has not been delivered yet…. 18.3.25

H
Sleepy Girl Mocktail - Tart Cherry
Helen (Australia)
Great taste

It tastes great, but is a bit hard to completely dissolve.

A
Magnesium Sparkling Water - Triple Pack of 24
April W. (Australia)
Not a fan

I was looking forward to these drinks but they are hard to drink with very little flavour. Maybe if I add lemon or something might help.

Hi April, we’re truly sorry to hear that the flavour didn’t meet your expectations, and its important we publish the negative reviews like this, with the positive (NB. we dont get many negatives..!)

We know our flavours dont appeal to 100% of people (does any flavour on earth appeal to everyone?), but we will be restocking Cherry soon, as well as introducing a new flavour in the coming weeks. Perhaps these might be more to your palate?

We hope to win you back!

Warm regards,

The Heylo Team

L
Magnesium Sampler Bundle
Leanne D. (Australia)
Very refreshing

Loved all flavours. Very refreshing and just a slight hint of taste with the lemon and blackcurrant. The plain was just as nice. Have placed my second order for 24 cans.

D
Magnesium Sampler Bundle
Di C. (Australia)

Magnesium Sampler Bundle

Load More